@@ -12,10 +12,9 @@ import os
 from pathlib import Path
 from typing import Any
 
-from coding_open_agent_tools._decorators import adk_tool, strands_tool
+from coding_open_agent_tools._decorators import strands_tool
 
 
-@adk_tool
 @strands_tool
 def detect_circular_imports(project_root: str) -> dict[str, Any]:
     """Detect circular import dependencies in a Python project.
@@ -85,7 +84,6 @@ def detect_circular_imports(project_root: str) -> dict[str, Any]:
     circular_chains: list[dict[str, Any]] = []
     visited: set[str] = set()
 
-    @strands_tool
     def detect_cycle(module: str, path: list[str]) -> None:
         if module in path:
             # Found circular import
@@ -134,7 +132,6 @@ def detect_circular_imports(project_root: str) -> dict[str, Any]:
     }
 
 
-@adk_tool
 @strands_tool
 def find_unused_imports(source_code: str) -> dict[str, Any]:
     """Find imported modules/names that are never used in the code.
@@ -230,7 +227,6 @@ def find_unused_imports(source_code: str) -> dict[str, Any]:
     }
 
 
-@adk_tool
 @strands_tool
 def identify_anti_patterns(source_code: str) -> dict[str, Any]:
     """Identify common Python anti-patterns and code smells.
@@ -397,7 +393,6 @@ def identify_anti_patterns(source_code: str) -> dict[str, Any]:
     }
 
 
-@adk_tool
 @strands_tool
 def check_test_coverage_gaps(source_file: str, test_file: str) -> dict[str, Any]:
     """Analyze test coverage gaps between source and test files.
